YearKind

Enum YearKind 

pub enum YearKind {
    Standard {
        negative: bool,
        digits: [Option<u8>; 4],
    },
    Big {
        value: i64,
    },
    Exponential {
        significand: i64,
        exponent: u32,
    },
}
The three syntactic forms a calendar year can take.

Variants



Standard

Four-digit year, possibly negative, possibly with X digits (None = unspecified digit).

Fields

negative: bool

True for years before year 0000 (written with a leading -).

digits: [Option<u8>; 4]

The four digits, most significant first; None is an X.



Big

Y-prefixed year beyond ±9999 (ISO 8601-2 4.7.2).

Fields

value: i64

The signed year value.



Exponential

Y…E… exponential year (ISO 8601-2 4.7.3).

Fields

significand: i64

Signed significand; the year is significand × 10^exponent.

exponent: u32

Power-of-ten exponent.