Relations

Struct Relations 

pub struct Relations { /* private fields */ }
The modality of every Relation between one pair of expressions, as computed by Edtf::relation.

Implementations

Source

impl Relations

pub const fn modality(self, r: Relation) -> Modality

The modality of one relation.

pub fn is_possible(self, r: Relation) -> bool

True if the relation holds for at least one completion pair (i.e. its modality is Possible or Definite).

pub fn is_definite(self, r: Relation) -> bool

True if the relation holds for every completion pair.

pub fn is_impossible(self, r: Relation) -> bool

True if the relation holds for no completion pair.

pub fn definite(self) -> Option<Relation>

The one relation that definitely holds, if any. At most one relation can be definite; only Before, After and Equal ever are.

pub fn possible(self) -> impl Iterator<Item = Relation>

The relations that hold for at least one completion pair, in canonical order. Never empty.