pub struct Relations { /* private fields */ }Expand description
The modality of every Relation between one pair of expressions, as
computed by Edtf::relation.
Implementations
Sourceimpl Relations
impl Relations
Sourcepub fn is_possible(self, r: Relation) -> bool
pub fn is_possible(self, r: Relation) -> bool
True if the relation holds for at least one completion pair
(i.e. its modality is Possible or Definite).
Sourcepub fn is_definite(self, r: Relation) -> bool
pub fn is_definite(self, r: Relation) -> bool
True if the relation holds for every completion pair.
Sourcepub fn is_impossible(self, r: Relation) -> bool
pub fn is_impossible(self, r: Relation) -> bool
True if the relation holds for no completion pair.